Index: installer/src/installer-lib/test/property_test.cpp |
=================================================================== |
--- a/installer/src/installer-lib/test/property_test.cpp |
+++ b/installer/src/installer-lib/test/property_test.cpp |
@@ -6,7 +6,7 @@ |
TEST( Property_Test, null ) |
{ |
/* |
* This is an extract of manual test code originally run from abp_close_ie DLL entry point. |
* This code relies on an MSI database opened for installation, which we don't need to access properties. |
* We can instead use an offline session, with the database opened outside Windows Installer. |
* That session class, though, isn't written yet. |
@@ -20,9 +20,9 @@ |
MSIHANDLE session_handle = 0; |
// The code in the body. |
- Immediate_Session session( session_handle, "abp_close_ie" ) ; |
+ ImmediateSession session( session_handle, "AbpCloseIe" ) ; |
session.log( L"Have session object" ) ; |
- Installation_Database db( session ) ; |
+ InstallationDatabase db( session ) ; |
session.log( L"Have database object" ) ; |
// Test: ensure that a property is present with its expected value. Exercises the conversion operator to String. |
@@ -6,7 +6,7 @@ |
{ |
/* |
- * This is an extract of manual test code originally run from abp_close_ie DLL entry point. |
+ * This is an extract of manual test code originally run from AbpCloseIe DLL entry point. |
* This code relies on an MSI database opened for installation, which we don't need to access properties. |
* We can instead use an offline session, with the database opened outside Windows Installer. |